| quad.form | R Documentation |
Functionality for evaluating quadratic forms.
If you want to use these functions, import them from the quadform package, which has more extensive functionality, and is maintained.
The quadform package defines quad3.form() et seq, not
quad.3form(), which was the old name. Function
quad.3form() will soon be deprecated.
quad.form(M, x)
quad.form.inv(M, x)
quad.tform(M, x)
quad3.form(M, left, right)
cprod(x, y)
ht(x)
M |
Square matrix of size |
x, y |
Matrix of size |
left, right |
In function |
See the quadform package for further detail.
See the quadform package for further detail.
Robin K. S. Hankin
optimize
jj <- matrix(rnorm(80),20,4)
M <- crossprod(jj,jj)
x <- matrix(rnorm(8),4,2)
jj.1 <- t(x) %*% M %*% x
jj.2 <- quad.form(M,x)
print(jj.1)
print(jj.2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.